Re: [PATCH] drm: fix drm_fb_xrgb8888_to_rgb888_dstclip()

2019-04-16 Thread Daniel Vetter
On Thu, Apr 11, 2019 at 06:49:32AM +0200, Gerd Hoffmann wrote:
> Oops, the __iomem annotation was added to the header file only.
> Add it to the implementation (and documentation) too.
> 
> Fixes: 5c5373b51bec ("drm: switch drm_fb_xrgb_to_rgb888_dstclip to accept 
> __iomem dst")
> Signed-off-by: Gerd Hoffmann 
> ---
>  drivers/gpu/drm/drm_format_helper.c | 6 +++---
>  1 file changed, 3 insertions(+), 3 deletions(-)
> 
> diff --git a/drivers/gpu/drm/drm_format_helper.c 
> b/drivers/gpu/drm/drm_format_helper.c
> index 319de608a088..da388012df2a 100644
> --- a/drivers/gpu/drm/drm_format_helper.c
> +++ b/drivers/gpu/drm/drm_format_helper.c
> @@ -230,7 +230,7 @@ static void drm_fb_xrgb_to_rgb888_line(u8 *dbuf, u32 
> *sbuf,
>  
>  /**
>   * drm_fb_xrgb_to_rgb888_dstclip - Convert XRGB to RGB888 clip buffer
> - * @dst: RGB565 destination buffer
> + * @dst: RGB565 destination buffer (iomem)
>   * @dst_pitch: destination buffer pitch
>   * @vaddr: XRGB source buffer
>   * @fb: DRM framebuffer
> @@ -241,9 +241,9 @@ static void drm_fb_xrgb_to_rgb888_line(u8 *dbuf, u32 
> *sbuf,
>   * support XRGB.
>   *
>   * This function applies clipping on dst, i.e. the destination is a
> - * full framebuffer but only the clip rect content is copied over.
> + * full (iomem) framebuffer but only the clip rect content is copied over.
>   */

All this nice kerneldoc isn't pulled into the docs in
Documentation/gpu/drm-kms-helper.rst anywhere. Can you pls fix that too?

Thanks, Daniel

> -void drm_fb_xrgb_to_rgb888_dstclip(void *dst, unsigned int dst_pitch,
> +void drm_fb_xrgb_to_rgb888_dstclip(void __iomem *dst, unsigned int 
> dst_pitch,
>  void *vaddr, struct drm_framebuffer *fb,
>  struct drm_rect *clip)
>  {
> -- 
> 2.18.1
> 

-- 
Daniel Vetter
Software Engineer, Intel Corporation
http://blog.ffwll.ch
___
dri-devel mailing list
dri-devel@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/dri-devel

Re: [PATCH] drm: fix drm_fb_xrgb8888_to_rgb888_dstclip()

2019-04-11 Thread Noralf Trønnes


Den 11.04.2019 06.49, skrev Gerd Hoffmann:
> Oops, the __iomem annotation was added to the header file only.
> Add it to the implementation (and documentation) too.
> 
> Fixes: 5c5373b51bec ("drm: switch drm_fb_xrgb_to_rgb888_dstclip to accept 
> __iomem dst")
> Signed-off-by: Gerd Hoffmann 
> ---

Reviewed-by: Noralf Trønnes 
___
dri-devel mailing list
dri-devel@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/dri-devel

[PATCH] drm: fix drm_fb_xrgb8888_to_rgb888_dstclip()

2019-04-10 Thread Gerd Hoffmann
Oops, the __iomem annotation was added to the header file only.
Add it to the implementation (and documentation) too.

Fixes: 5c5373b51bec ("drm: switch drm_fb_xrgb_to_rgb888_dstclip to accept 
__iomem dst")
Signed-off-by: Gerd Hoffmann 
---
 drivers/gpu/drm/drm_format_helper.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/gpu/drm/drm_format_helper.c 
b/drivers/gpu/drm/drm_format_helper.c
index 319de608a088..da388012df2a 100644
--- a/drivers/gpu/drm/drm_format_helper.c
+++ b/drivers/gpu/drm/drm_format_helper.c
@@ -230,7 +230,7 @@ static void drm_fb_xrgb_to_rgb888_line(u8 *dbuf, u32 
*sbuf,
 
 /**
  * drm_fb_xrgb_to_rgb888_dstclip - Convert XRGB to RGB888 clip buffer
- * @dst: RGB565 destination buffer
+ * @dst: RGB565 destination buffer (iomem)
  * @dst_pitch: destination buffer pitch
  * @vaddr: XRGB source buffer
  * @fb: DRM framebuffer
@@ -241,9 +241,9 @@ static void drm_fb_xrgb_to_rgb888_line(u8 *dbuf, u32 
*sbuf,
  * support XRGB.
  *
  * This function applies clipping on dst, i.e. the destination is a
  * full framebuffer but only the clip rect content is copied over.
  */
-void drm_fb_xrgb_to_rgb888_dstclip(void *dst, unsigned int dst_pitch,
+void drm_fb_xrgb_to_rgb888_dstclip(void __iomem *dst, unsigned int 
dst_pitch,
   void *vaddr, struct drm_framebuffer *fb,
   struct drm_rect *clip)
@@ -241,9 +241,9 @@ static void drm_fb_xrgb_to_rgb888_line(u8 *dbuf, u32 
  *
  * This function applies clipping on dst, i.e. the destination is a
- * full framebuffer but only the clip rect content is copied over.
+ * full (iomem) framebuffer but only the clip rect content is copied over.
  */
 {
-- 
2.18.1

___
dri-devel mailing list
dri-devel@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/dri-devel